@@ -1,15 +1,15 @@
 #!/usr/bin/env python
 
 """
-TODO: Modify module doc.
+Library for materials symmetry analysis
 """
 
 from __future__ import division
 
 __author__ = "Shyue Ping Ong"
-__copyright__ = "Copyright 2012, The Materials Project"
+__copyright__ = "Copyright 2013, The Materials Virtual Lab"
 __version__ = "0.1"
 __maintainer__ = "Shyue Ping Ong"
-__email__ = "shyuep@gmail.com"
+__email__ = "ongsp@ucsd.edu"
 __date__ = "4/4/14"
 
